@@ -111,7 +111,7 @@ static gchar* atom10_parse_content_construct(xmlNodePtr cur) {
 		}
 	} else {
 		gchar *type;
-		gboolean escapeAsText, includeChildTags;
+		gboolean escapeAsText, includeChildTags = TRUE;
 		xmlChar *baseURL = NULL;
 
 		/* determine encoding mode */
@@ -155,9 +155,8 @@ static gchar* atom10_parse_content_construct(xmlNodePtr cur) {
 		
 		if (escapeAsText) {
 			gchar *tmp;
-
 			g_strchug(g_strchomp(ret));
-			
+
 			if (type == NULL || !strcasecmp(type, "text"))
 				tmp = atom10_mark_up_text_content(ret);
 			else
@@ -195,12 +194,14 @@ static gchar* atom10_parse_text_construct(xmlNodePtr cur, gboolean htmlified) {
 	/* This that need to be de-encoded and should not contain sub-tags.*/
 	if (NULL == type || !strcmp(type, "text")) {
 		ret = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
-		g_strchug(g_strchomp(ret));
+		if(ret) {
+			g_strchug(g_strchomp(ret));
 		
-		if (htmlified) {
-			tmp = atom10_mark_up_text_content(ret);
-			g_free(ret);
-			ret = tmp;
+			if (htmlified) {
+				tmp = atom10_mark_up_text_content(ret);
+				g_free(ret);
+				ret = tmp;
+			}
 		}
 	} else if (!strcmp(type, "html")) {
 		ret = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
