@@ -131,11 +131,15 @@ void ui_init(int mainwindowState) {
 	}
 
 #ifdef USE_DBUS
-	/* Start listening on the dbus for new subscriptions */
-	debug0(DEBUG_GUI, "Registering with DBUS...");
-	ui_feedlist_dbus_connect();
+	if(!getBooleanConfValue(DISABLE_DBUS)) {
+		/* Start listening on the dbus for new subscriptions */	
+		debug0(DEBUG_GUI, "Registering with DBUS...");
+		ui_feedlist_dbus_connect();
+	} else {
+		g_print("DBUS disabled by user request...");
+	}
 #else
-	debug0(DEBUG_GUI, "No DBUS support active.");
+	debug0(DEBUG_GUI, "Compiled without DBUS support.");
 #endif
 
 	/* setup one minute timer for automatic updating, and try updating now */
@@ -145,13 +149,18 @@ void ui_init(int mainwindowState) {
 	if (mainwindowState == MAINWINDOW_ICONIFIED || (mainwindowState == MAINWINDOW_HIDDEN && ui_tray_get_count() == 0)) {
 		gtk_window_iconify(GTK_WINDOW(mainwindow));
 		gtk_widget_show(mainwindow);
-	} else if (mainwindowState == MAINWINDOW_SHOWN)
+	} else if (mainwindowState == MAINWINDOW_SHOWN) {
 		gtk_widget_show(mainwindow);
-	else
+	} else {
 		/* Needed so that the window structure can be
 		   accessed... otherwise will GTK warning when window is
 		   shown by clicking on notification icon. */
-		gtk_widget_realize(GTK_WIDGET(mainwindow)); 
+		// gtk_widget_realize(GTK_WIDGET(mainwindow)); 
+		// Does not work with gtkmozembed...
+		
+		gtk_widget_show(mainwindow);
+		gtk_widget_hide(mainwindow);
+	}
 	ui_mainwindow_finish(mainwindow); /* Ugly hack to make mozilla work */
 		
 }
