@@ -206,7 +206,7 @@ feedHandlerPtr feed_parse(feedPtr fp, gchar *data, size_t dataLength, gboolean a
 			debug1(DEBUG_UPDATE, "HTML detected, starting feed auto discovery (%s)", feed_get_source(fp));
 			if(NULL != (source = html_auto_discover_feed(data, feed_get_source(fp)))) {
 				/* now download the first feed link found */
-				struct request *request = download_request_new(NULL);
+				struct request *request = download_request_new();
 				debug1(DEBUG_UPDATE, "feed link found: %s", source);
 				request->source = g_strdup(source);
 				download_process(request);
@@ -710,11 +710,14 @@ void feed_add_item(feedPtr fp, itemPtr new_ip) {
 				item_set_update_status(old_ip, TRUE);
 				metadata_list_free(old_ip->metadata);
 				old_ip->metadata = new_ip->metadata;
+				new_ip->metadata = NULL;
 				vfolder_update_item(old_ip);
 				debug0(DEBUG_VERBOSE, "-> item already existing and was updated");
 			} else {
 				debug0(DEBUG_VERBOSE, "-> item already exists");
 			}
+			
+			item_free(new_ip);
 		}
 	} else {
 		/* in case of vfolder just add the item */
