@@ -353,6 +353,12 @@ void ui_feed_process_update_result(struct request *request) {
 	fp->needsCacheSave = TRUE;
 	
 	feed_set_available(fp, TRUE);
+	
+	/* note this is to update the feed URL on permanent redirects */
+	if(0 != strcmp(request->source, feed_get_source(fp))) {
+		feed_set_source(fp, request->source);
+		ui_mainwindow_set_status_bar(_("The URL of \"%s\" has changed permanently and was updated"), feed_get_title(fp));
+	}
 
 	if(401 == request->httpstatus) { /* unauthorized */
 		feed_set_available(fp, FALSE);
@@ -367,13 +373,7 @@ void ui_feed_process_update_result(struct request *request) {
 	} else if(NULL != request->data) {
 		feed_set_lastmodified(fp, request->lastmodified);
 		feed_set_etag(fp, request->etag);
-		
-		/* note this is to update the feed URL on permanent redirects */
-		if(0 != strcmp(request->source, feed_get_source(fp))) {
-			feed_set_source(fp, request->source);
-			ui_mainwindow_set_status_bar(_("The URL of \"%s\" has changed permanently and was updated"), feed_get_title(fp));
-		}
-		
+			
 		/* we save all properties that should not be overwritten in all cases */
 		old_update_interval = feed_get_update_interval(fp);
 		old_title = g_strdup(feed_get_title(fp));
@@ -382,8 +382,10 @@ void ui_feed_process_update_result(struct request *request) {
 		/* parse the new downloaded feed into fp */
 		fhp = feed_parse(fp, request->data, request->size, request->flags & FEED_REQ_AUTO_DISCOVER);
 		if(fhp == NULL) {
-			feed_set_available(fp, FALSE);
+			gchar	*tmp = fp->parseErrors;
 			fp->parseErrors = g_strdup_printf(_("<p>Could not detect the type of this feed! Please check if the source really points to a resource provided in one of the supported syndication formats!</p>%s"), fp->parseErrors);
+			g_free(tmp);
+			feed_set_available(fp, FALSE);
 		} else {
 			fp->fhp = fhp;
 			
@@ -399,9 +401,6 @@ void ui_feed_process_update_result(struct request *request) {
 			else
 				feed_set_update_interval(fp, old_update_interval);
 				
-			g_free(old_title);
-			g_free(old_source);
-
 			ui_mainwindow_set_status_bar(_("\"%s\" updated..."), feed_get_title(fp));
 
 			itemlist_reload((nodePtr)fp);
@@ -409,6 +408,8 @@ void ui_feed_process_update_result(struct request *request) {
 			if(request->flags & FEED_REQ_SHOW_PROPDIALOG)
 				ui_feed_propdialog_new(GTK_WINDOW(mainwindow),fp);
 		}
+		g_free(old_title);
+		g_free(old_source);
 	} else {	
 		ui_mainwindow_set_status_bar(_("\"%s\" is not available"), feed_get_title(fp));
 		feed_set_available(fp, FALSE);
@@ -543,11 +544,50 @@ ui_feedlist_dbus_subscribe (DBusConnection *connection, DBusMessage *message)
 	reply = dbus_message_new_method_return (message);
 	if (reply != NULL)
 	{
-#if (DBUS_VERSION == 1)
-		dbus_message_append_args (reply, DBUS_TYPE_BOOLEAN, done,DBUS_TYPE_INVALID);
-#elif (DBUS_VERSION == 2)
 		dbus_message_append_args (reply, DBUS_TYPE_BOOLEAN, &done,DBUS_TYPE_INVALID);
-#endif
+		dbus_connection_send (connection, reply, NULL);
+		dbus_message_unref (reply);
+		return DBUS_HANDLER_RESULT_HANDLED;
+	}
+	else
+		return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+}
+
+static DBusHandlerResult
+ui_feedlist_dbus_set_online (DBusConnection *connection, DBusMessage *message)
+{
+	DBusError error;
+	DBusMessage *reply;
+	gboolean b;
+	gboolean done = TRUE;
+	
+	/* Retreive the dbus message arguments (the online status) */	
+	dbus_error_init (&error);
+	if (!dbus_message_get_args (message, &error, DBUS_TYPE_BOOLEAN, &b, DBUS_TYPE_INVALID))
+	{
+		fprintf (stderr, "*** ui_feedlist.c: Error while retreiving message parameter, expecting a boolean: %s | %s\n", error.name,  error.message);
+		reply = dbus_message_new_error (message, error.name, error.message);
+		dbus_connection_send (connection, reply, NULL);
+		dbus_message_unref (reply);
+		dbus_error_free(&error);
+		return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+	}
+	dbus_error_free(&error);
+
+
+	/* Set online status */
+	download_set_online(b);
+
+	/* Update UI part: snip from ui_mainwindow.c:on_onlinebtn_clicked() */
+	ui_mainwindow_update_onlinebtn();
+	ui_tray_update();
+	GTK_CHECK_MENU_ITEM(lookup_widget(mainwindow, "work_offline"))->active = !b;
+
+	/* Acknowledge the new feed by returning true */
+	reply = dbus_message_new_method_return (message);
+	if (reply != NULL)
+	{
+		dbus_message_append_args (reply, DBUS_TYPE_BOOLEAN, &done,DBUS_TYPE_INVALID);
 		dbus_connection_send (connection, reply, NULL);
 		dbus_message_unref (reply);
 		return DBUS_HANDLER_RESULT_HANDLED;
@@ -570,6 +610,9 @@ ui_feedlist_dbus_message_handler (DBusConnection *connection, DBusMessage *messa
 	method = dbus_message_get_member (message);
 	if (strcmp (DBUS_RSS_METHOD, method) == 0)
 		return ui_feedlist_dbus_subscribe (connection, message);
+	else
+	if (strcmp (DBUS_RSS_SET_ONLINE_METHOD, method) == 0)
+		return ui_feedlist_dbus_set_online (connection, message);
 	else
 		return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
@@ -597,13 +640,8 @@ ui_feedlist_dbus_connect ()
 	dbus_connection_setup_with_g_main (connection, NULL);
 	    
 	/* Register for the FeedReader service on the bus, so we get method calls */
-#if (DBUS_VERSION == 1)
-	dbus_bus_acquire_service (connection, DBUS_RSS_SERVICE, 0, &error);
-#elif (DBUS_VERSION == 2)
 	dbus_bus_request_name (connection, DBUS_RSS_SERVICE, 0, &error);
-#else
-#error Unknown DBUS version passed to ui_feedlist
-#endif
+
 	if (dbus_error_is_set (&error))
 	{
 		fprintf (stderr, "*** ui_feedlist.c: Failed to get dbus service: %s | %s\n", error.name, error.message);
