@@ -33,6 +33,7 @@
 #endif
 
 #include <libgtkhtml/gtkhtml.h>
+#include <libgtkhtml/view/htmlselection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
@@ -212,17 +213,22 @@ static void on_url(HtmlView *view, const char *url, gpointer user_data) {
 	selectedURL = NULL;
 
 	if(NULL != url) {
+
 		gdk_window_set_cursor(GDK_WINDOW(gtk_widget_get_parent_window(GTK_WIDGET(view))), link_cursor);
-		absURL = common_build_url(url, g_object_get_data(G_OBJECT(HTML_VIEW(view)->document), "liferea-base-uri"));
-		if(absURL != NULL) {
-			selectedURL = g_strdup(absURL);
-			ui_mainwindow_set_status_bar("%s", selectedURL);
-			xmlFree(absURL);
+		if(strstr(url, "://")) {
+			selectedURL = g_strdup(url);
+		} else {
+			absURL = common_build_url(url, g_object_get_data(G_OBJECT(HTML_VIEW(view)->document), "liferea-base-uri"));
+			if(absURL != NULL) {
+				selectedURL = g_strdup(absURL);
+				xmlFree(absURL);
+			}
 		}
 	} else {
 		gdk_window_set_cursor(GDK_WINDOW(gtk_widget_get_parent_window(GTK_WIDGET(view))), NULL);
-		ui_mainwindow_set_status_bar("");
 	}
+	
+	ui_mainwindow_set_status_bar("%s", selectedURL?selectedURL:"");
 }
 
 static gboolean request_object (HtmlView *view, GtkWidget *widget, gpointer user_data) {
@@ -276,6 +282,12 @@ static void gtkhtml2_title_changed(HtmlDocument *doc, const gchar *new_title, gp
 /* adds a differences diff to the actual zoom level */
 static void change_zoom_level(GtkWidget *scrollpane, gfloat zoomLevel) {
 	GtkWidget *htmlwidget = gtk_bin_get_child(GTK_BIN(scrollpane));
+	
+	/* Clearing the selection is a workaround to avoid 
+	   crashes when changing the zoomlevel as reported
+	   in SF #1509741 */
+	html_selection_clear(HTML_VIEW(htmlwidget));
+	
 	html_view_set_magnification(HTML_VIEW(htmlwidget), zoomLevel);
 }
 
