@@ -617,6 +617,8 @@ void ui_feedlist_add(folderPtr parent, nodePtr node, gint position) {
 	ui_feedlist_update();
 }
 
+#define FEED_PROTOCOL_PREFIX "feed://"
+
 void ui_feedlist_new_subscription(const gchar *source, const gchar *filter, gint flags) {
 	feedPtr			fp;
 	gchar			*tmp;
@@ -629,8 +631,14 @@ void ui_feedlist_new_subscription(const gchar *source, const gchar *filter, gint
 	tmp = conf_new_id();
 	feed_set_id(fp, tmp);
 	g_free(tmp);
+	
+	g_assert(source);
+	tmp = g_strdup(source);
+	g_strstrip(tmp);
+	if(tmp == strstr(tmp, FEED_PROTOCOL_PREFIX))
+		tmp += strlen(FEED_PROTOCOL_PREFIX);
 
-	feed_set_source(fp, source);
+	feed_set_source(fp, tmp);
 	feed_set_title(fp, _("New subscription"));
 	feed_set_filter(fp, filter);
 	parent = ui_feedlist_get_target_folder(&pos);
@@ -642,6 +650,7 @@ void ui_feedlist_new_subscription(const gchar *source, const gchar *filter, gint
 	feed_schedule_update(fp, flags | FEED_REQ_PRIORITY_HIGH | FEED_REQ_DOWNLOAD_FAVICON | FEED_REQ_AUTH_DIALOG);
 	
 	/*ui_show_error_box(_("The newly created feed's type could not be detected! Please check if the source really points to a resource provided in one of the supported syndication formats"));*/
+	g_free(tmp);
 	
 	debug_exit("ui_feedlist_new_subscription");
 }
