@@ -222,6 +222,7 @@ void ui_itemlist_clear(void) {
 void ui_itemlist_update_item(itemPtr ip) {
 	GtkTreeIter	*iter;
 	gchar		*title, *label, *time_str, *esc_title, *esc_time_str, *tmp;
+	const gchar 	*direction_marker;
 	GdkPixbuf	*icon = NULL, *favicon;
 
 	/* favicon for feed icon column (visible in folders/vfolders/searches) */
@@ -251,17 +252,19 @@ void ui_itemlist_update_item(itemPtr ip) {
 	esc_title = g_markup_escape_text(title, -1);
 	esc_title = g_strstrip(esc_title);
 	
+	direction_marker = common_get_direction_mark(ip->fp->title);
+
 	if(FALSE == item_get_read_status(ip)) {
 		time_str = g_strdup_printf("<span weight=\"bold\">%s</span>", esc_time_str);
-		label = g_strdup_printf("<span weight=\"bold\">%s</span>", esc_title);
+		label = g_strdup_printf("%s<span weight=\"bold\">%s</span>", direction_marker, esc_title);
 		icon = icons[ICON_UNREAD];
 	} else if(TRUE == item_get_update_status(ip)) {
 		time_str = g_strdup_printf("<span weight=\"bold\" color=\"#333\">%s</span>", esc_time_str);
-		label = g_strdup_printf("<span weight=\"bold\" color=\"#333\">%s</span>", esc_title);
+		label = g_strdup_printf("%s<span weight=\"bold\" color=\"#333\">%s</span>", direction_marker, esc_title);
 		icon = icons[ICON_UPDATED];
 	} else {
 		time_str = g_strdup(esc_time_str);
-		label = g_strdup(esc_title);
+		label = g_strdup_printf("%s%s", direction_marker, esc_title);
 		icon = icons[ICON_READ];
 	}
 	g_free(esc_title);
