@@ -37,15 +37,17 @@ static gboolean on_tab_url_entry_activate(GtkWidget *widget, gpointer user_data)
 	return TRUE;
 }
 
-static gboolean on_tab_close_clicked(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
-	int i;	
+static gboolean on_tab_close_clicked(GtkWidget *button, GdkEvent *event, gpointer user_data) {
+	GtkNotebook	*notebook;
+	int 		i;
 	
-	i = gtk_notebook_get_current_page(GTK_NOTEBOOK(lookup_widget(mainwindow, "browsertabs")));
-	gtk_notebook_remove_page(GTK_NOTEBOOK(lookup_widget(mainwindow, "browsertabs")), i);
+	notebook = GTK_NOTEBOOK(lookup_widget(mainwindow, "browsertabs"));
+	i = gtk_notebook_get_current_page(notebook);
+	gtk_notebook_remove_page(notebook, i);
 	
 	/* check if all tabs are closed */
-	if(1 == gtk_notebook_get_n_pages(GTK_NOTEBOOK(lookup_widget(mainwindow, "browsertabs"))))
-		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(lookup_widget(mainwindow, "browsertabs")), FALSE);
+	if(1 == gtk_notebook_get_n_pages(notebook))
+		gtk_notebook_set_show_tabs(notebook, FALSE);
 		
 	return TRUE;
 }
@@ -148,7 +150,7 @@ GtkWidget* ui_tabs_new(const gchar *url, const gchar *title, gboolean activate)
 	
 	if((TRUE == activate) && (i != -1))
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(lookup_widget(mainwindow, "browsertabs")), i);
-	
+
 	if(NULL != url)	
 		ui_htmlview_launch_URL(htmlview, (gchar *)url, UI_HTMLVIEW_LAUNCH_INTERNAL);
 	return htmlview;
